/* rll04.c --- encoder/decoder for RLL 0,4 code
 * (C) 2000, C. Bond. All rights reserved.
 *
 * These endec modules support encoding and decoding of 8/9 rate RLL 0,4
 * codes. In fact, any 8/9 rate code which can be fully concatenated is
 * acceptable. The method used is simply to map 8-bit sequences to 9-bit
 * sequences and the reverse according to a user provided code table.
 */
int rll04_encoder(unsigned char *raw,unsigned char *code,
	int *encodetable,int n)
{
	int icount,ocount,temp;
	int i,itemp,otemp;
	
/* check for valid input parameter */
	if (n < 8) return 1;
	
	icount=ocount=0;
	
	while (icount < n-8) {
		temp = 0;
		for (i=0;i<8;i++)
			temp += (raw[icount++] << i);
		otemp=encodetable[temp];
		for (i=0;i<9;i++)
			code[ocount++] = (otemp >> i) & 1;
	}
	return 0;
}


int rll04_decoder(unsigned char *code,unsigned char *data,
	int *decodetable,int n)
{
	int icount,ocount,temp;
	int i,itemp,otemp;
	
/* check for valid input parameter */
	if (n < 9) return 1;
	
	icount=ocount=0;
	
	while (icount < n-9) {
		temp = 0;
		for (i=0;i<9;i++)
			temp += (code[icount++] << i);
		otemp=decodetable[temp];
		for (i=0;i<8;i++)
			data[ocount++] = (otemp >> i) & 1;
	}
	return 0;
}
	
