/* rll04gen.c -- Generate code table for 8/9 rate RLL 04/4 code.
 *
 * (C) 2000, C. Bond. All rights reserved.
 *
 * This is a simple, direct method for generating an 8/9 rate code satisfying
 * RLL 0,4/4 rules. That is, for an arbitrary binary input stream, there will
 * be no more than 4 consecutive zeros, or more than 4 consecutive interlaced
 * zeros. Note that passing the encoded data through a precoder will add
 * zeros, so the PLL must actually handle more than 4 consecutive zeros.
 *
 * The number of valid codewords is slightly more than needed, so some of
 * them can be excluded to satisfy other requirements.
 */

#include <stdio.h>

void main()
{
    int d[512];
    int i,idx;
    FILE *outfile;

    idx = 0;
    for (i=0;i<512;i++) {
        if ((i & 0x1c0) == 0) continue; /* 3 zeros at left end */
        if ((i & 0x07) == 0) continue;  /* 3 zeros at right end */
        if ((i & 0x1f) == 0) continue;  /* 5 internal zeros */
        if ((i & 0x3e) == 0) continue;  /*       "      */
        if ((i & 0x7c) == 0) continue;  /*       "      */
        if ((i & 0xf8) == 0) continue;  /*       "      */
        if ((i & 0x2a) == 0) continue;  /* 3 right interleaved zeros */
        if ((i & 0x15) == 0) continue;  /*           "               */
        if ((i & 0x150) == 0) continue; /* 3 left interleaved zeros  */
        if ((i & 0xa8) == 0) continue;  /*           "               */
        d[idx++] = i;
    }
    outfile = fopen("rll04_4.tbl","wt");
    for (i =0;i < idx;i++) {
        fprintf(outfile,"%d\n",d[i]);
    }
    fclose(outfile);
}

